#
# spec file for package healpix
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpkg chealpix
%define clib lib%{cpkg}0
%define cxxpkg healpix_cxx
%define cxxlib lib%{cxxpkg}4
Name:           healpix
Version:        3.83
Release:        1.2
Summary:        Data Analysis, Simulations and Visualization on the Sphere
License:        GPL-2.0-or-later
URL:            https://healpix.sourceforge.io
Source:         %{name}-%{version}.tar.xz
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cfitsio)
BuildRequires:  pkgconfig(libsharp)
BuildRequires:  pkgconfig(zlib)

%description
HEALPix is a Hierarchical, Equal Area, and iso-Latitude Pixelation of the
sphere designed to support efficiently (1) local operations on the pixel set,
(2) a hierarchical tree structure for multi-resolution applications, and (3)
the global Fast Spherical Harmonic transform.

%package -n %{clib}
Summary:        Shared library for healpix - C bindings

%description -n %{clib}
HEALPix is a Hierarchical, Equal Area, and iso-Latitude Pixelation of the
sphere designed to support efficiently (1) local operations on the pixel set,
(2) a hierarchical tree structure for multi-resolution applications, and (3)
the global Fast Spherical Harmonic transform.

This package provides the shared library for the C bindings of healpix.

%package -n %{cpkg}-devel
Summary:        Headers and devel files for healpix - C bindings
Requires:       %{clib} = %{version}
Requires:       pkgconfig(cfitsio)
Requires:       pkgconfig(libsharp)

%description -n %{cpkg}-devel
HEALPix is a Hierarchical, Equal Area, and iso-Latitude Pixelation of the
sphere designed to support efficiently (1) local operations on the pixel set,
(2) a hierarchical tree structure for multi-resolution applications, and (3)
the global Fast Spherical Harmonic transform.

This package provides the headers and devel files for building apps with
healpix in the C language.

%package -n %{cxxlib}
Summary:        Shared library for healpix - C++ bindings

%description -n %{cxxlib}
HEALPix is a Hierarchical, Equal Area, and iso-Latitude Pixelation of the
sphere designed to support efficiently (1) local operations on the pixel set,
(2) a hierarchical tree structure for multi-resolution applications, and (3)
the global Fast Spherical Harmonic transform.

This package provides the shared library for the C++ bindings of healpix.

%package -n %{cxxpkg}-devel
Summary:        Headers and devel files for healpix - C++ bindings
Requires:       %{cxxlib} = %{version}
Requires:       pkgconfig(cfitsio)
Requires:       pkgconfig(libsharp)
Requires:       pkgconfig(zlib)

%description -n %{cxxpkg}-devel
HEALPix is a Hierarchical, Equal Area, and iso-Latitude Pixelation of the
sphere designed to support efficiently (1) local operations on the pixel set,
(2) a hierarchical tree structure for multi-resolution applications, and (3)
the global Fast Spherical Harmonic transform.

This package provides the headers and devel files for building apps with
healpix in the C++ language.

%prep
%autosetup -p1

%build
# Top-level configure script is useless, need to use individual dir scripts
for d in src/C/autotools src/cxx
do
pushd ${d}
autoreconf -fvi
%configure --disable-static
%make_build
popd
done

%install
for d in src/C/autotools src/cxx
do
pushd ${d}
%make_install
popd
done

find %{buildroot} -type f -name "*.la" -delete -print

%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
for d in src/C/autotools src/cxx
do
pushd ${d}
%make_build check
popd
done

%post -n %{clib} -p /sbin/ldconfig
%postun -n %{clib} -p /sbin/ldconfig
%post -n %{cxxlib} -p /sbin/ldconfig
%postun -n %{cxxlib} -p /sbin/ldconfig

%files
%license COPYING READ_Copyrights_Licenses.txt
%doc README
%{_bindir}/*

%files -n %{clib}
%license COPYING READ_Copyrights_Licenses.txt
%{_libdir}/lib%{cpkg}.so.*

%files -n %{cpkg}-devel
%license COPYING READ_Copyrights_Licenses.txt
%{_libdir}/lib%{cpkg}.so
%{_libdir}/pkgconfig/%{cpkg}.pc
%{_includedir}/%{cpkg}.h

%files -n %{cxxlib}
%license COPYING READ_Copyrights_Licenses.txt
%{_libdir}/lib%{cxxpkg}.so.*

%files -n %{cxxpkg}-devel
%license COPYING READ_Copyrights_Licenses.txt
%{_libdir}/lib%{cxxpkg}.so
%{_libdir}/pkgconfig/%{cxxpkg}.pc
%{_includedir}/%{cxxpkg}/

%changelog
* Fri Dec 20 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.83:
  * General:
  - Support for intel ifx compiler.
  - Proper detection of python versions 3.10 and above.
  * C++:
  - bug fix in query_polygon where pixels might be missing in
    some situations where polygon edges were parallel to the
    equator (gh#healpy/healpy#904).
  - bug fix in query_disc_inclusive where pixels could be
    missing at locations exactly azimuthally opposite to the
    disc center (gh#healpy/healpy#968).
- Update c++ shlib name to keep with so version update (3 -> 4).
* Mon Oct  9 2023 Atri Bhattacharya <badshah400@gmail.com>
- Recompress to xz during buildtime to reduce src.rpm size.
* Wed Oct  4 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.82:
  * C: Corrected documentation of pix2vec routines.
  * C++: Cfitsio 4.1.0 (March 2022) and higher now properly
    supported.
  * Fortran 90: Bug corrections in input_map and
    read_fits_partial.
- Switch to obs_scm instead of tar_scm service; only recompress to
  tar at buildtime.
* Mon Jul 11 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.81:
  * Cfitsio 4.0.0 (Jul 2021) and higher now properly supported.
  * Introduced workarounds for some minor GDL and FL limitations.
- New BuildRequires: pkgconfig(zlib) and also Requires for c++
  devel package.
- Drop healpix-cfitsio-version-format-change.patch: incorporated
  upstream.
* Wed Aug 18 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.80:
  * General:
  - addition of SHARP_PARAL and CXX_PARAL to control the
    parallel implementation of the libsharp library and C++
    library and codes.
  - PYTHON now defaults to python3.
  * C++:
  - the line-integral convolution interface is now accessible
    not only from the command line, but also via C++ calls, to
    allow calling from healpy.
  - some internals were restructured to allow easier integration
    with SWIG.
  * Fortran 90 facilities and subroutines:
  - Improvement of query_disc routine in inclusive mode.
  - The routines alm2map_spin and map2alm_spin now accept any
    (integer) spin values |s|>=0, but the scalar routines
    alm2map and map2alm are still recommended for vanishing spin
    (s=0).
  - Correction of bugs preventing the compilation with versions
    10.* of gfortran.
  - Fixed bug affecting map2gif when compiled with versions 10.*
    of gfortran and gcc.
- Add healpix-cfitsio-version-format-change.patch -- Adapt to new
  three-number version format of cfitsio
  [https://sourceforge.net/p/healpix/bugs/122/].
* Tue Nov 10 2020 Atri Bhattacharya <badshah400@gmail.com>
- Use _service file to build source tarball from svn repo directly
  while omitting idl source files: this avoids licensing issues
  that the idl source files carry.
* Sun Aug 16 2020 Atri Bhattacharya <badshah400@gmail.com>
- Initial package
